@@ -7,11 +7,20 @@ from starlite.logging.standard import resolve_handlers
 
 
 class QueueListenerHandler(QueueHandler):  # type: ignore
-    """
-    Configures queue listener and handler to support non-blocking logging configuration.
-    """
-
     def __init__(self, handlers: List[Any], respect_handler_level: bool = False, queue: Queue = Queue(-1)):
+        """
+        Configures queue listener and handler to support non-blocking logging configuration.
+
+        Requires `picologging`, install with:
+        ```shell
+        $ pip install starlite[picologging]
+        ```
+
+        Args:
+            handlers (list): list of handler names.
+            respect_handler_level (bool): A handler’s level is respected (compared with the level for the message) when
+                deciding whether to pass messages to that handler.
+        """
         super().__init__(queue)
         self.handlers = resolve_handlers(handlers)
         self._listener: QueueListener = QueueListener(
