@@ -1,5 +1,5 @@
 from copy import copy
-from typing import TYPE_CHECKING, Any, Dict, List, cast
+from typing import TYPE_CHECKING, Dict, List, cast
 
 from pydantic.fields import Undefined
 from pydantic_openapi_schema.v3_1_0.parameter import Parameter
@@ -20,10 +20,11 @@ if TYPE_CHECKING:
 
     from starlite.handlers import BaseRouteHandler
     from starlite.provide import Provide
+    from starlite.routes.base import PathParameterDefinition
 
 
 def create_path_parameter_schema(
-    path_parameter: Dict[str, Any], field: "ModelField", generate_examples: bool
+    path_parameter: "PathParameterDefinition", field: "ModelField", generate_examples: bool
 ) -> "Schema":
     """Create a path parameter from the given path_param definition"""
     field.sub_fields = None
@@ -74,7 +75,10 @@ class ParameterCollection:
 
 
 def create_parameter(
-    model_field: "ModelField", parameter_name: str, path_parameters: List[Dict[str, Any]], generate_examples: bool
+    model_field: "ModelField",
+    parameter_name: str,
+    path_parameters: List["PathParameterDefinition"],
+    generate_examples: bool,
 ) -> Parameter:
     """
     Creates an OpenAPI Parameter instance
@@ -121,7 +125,7 @@ def get_recursive_handler_parameters(
     model_field: "ModelField",
     dependencies: Dict[str, "Provide"],
     route_handler: "BaseRouteHandler",
-    path_parameters: List[Dict[str, Any]],
+    path_parameters: List["PathParameterDefinition"],
     generate_examples: bool,
 ) -> List[Parameter]:
     """Create and return parameters for a handler. If the provided field is not a dependency,
@@ -145,7 +149,7 @@ def get_layered_parameter(
     field_name: str,
     signature_model_field: "ModelField",
     layered_parameters: Dict[str, "ModelField"],
-    path_parameters: List[Dict[str, Any]],
+    path_parameters: List["PathParameterDefinition"],
     generate_examples: bool,
 ) -> Parameter:
     """Create a layered parameter for a given signature model field.
@@ -184,7 +188,7 @@ def get_layered_parameter(
 def create_parameter_for_handler(
     route_handler: "BaseRouteHandler",
     handler_fields: Dict[str, "ModelField"],
-    path_parameters: List[Dict[str, Any]],
+    path_parameters: List["PathParameterDefinition"],
     generate_examples: bool,
 ) -> List[Parameter]:
     """
